@@ -214,6 +214,9 @@ SERVICE_VERSIONS = {
     "dts": [
         "2018-03-30"
     ],
+    "eb": [
+        "2021-04-16"
+    ],
     "ecc": [
         "2018-12-13"
     ],
